Crate component_shape_mcp_macros

Crate component_shape_mcp_macros 

Derive Macros

McpJsonSchema
Derive JSON Schema metadata for structs, transparent newtypes, and fieldless enums used in MCP tool schemas.
McpToolInput
Derive a top-level MCP input schema and strict MCP argument decoding for a named tool input struct.